OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Pridėta į mėgstamus",
    "Removed from favorites" : "Pašalintas iš mėgstamų",
    "You added {file} to your favorites" : "Pridėjote {file} į savo mėgstamus",
    "You removed {file} from your favorites" : "Pašalinote {file} iš mėgstamų",
    "Favorites" : "Mėgstami",
    "File changes" : "Failo pakeitimai",
    "Created by {user}" : "Sukūrė {user}",
    "Changed by {user}" : "Pakeitė {user}",
    "Deleted by {user}" : "Ištrynė {user}",
    "Restored by {user}" : "Atkūrė {user}",
    "Renamed by {user}" : "Pervadino {user}",
    "Moved by {user}" : "Perkėlė {user}",
    "\"remote account\"" : "„nuotolinė paskyra“",
    "You created {file}" : "Jūs sukūrėte {file}",
    "You created an encrypted file in {file}" : "Sukūrėte užšifruotą failą {file}",
    "{user} created {file}" : "{user} sukūrė {file}",
    "{user} created an encrypted file in {file}" : "{user} sukūrė užšifruotą failą {file}",
    "{file} was created in a public folder" : "{file} buvo sukurtas viešajame aplanke",
    "You changed {file}" : "Jūs pakeitėte {file}",
    "You changed an encrypted file in {file}" : "Pakeitėte užšifruotą failą {file}",
    "{user} changed {file}" : "{user} pakeitė {file}",
    "{user} changed an encrypted file in {file}" : "{user} pakeitė užšifruotą failą {file}",
    "You deleted {file}" : "Jūs ištrynėte {file}",
    "You deleted an encrypted file in {file}" : "Jūs ištrynėte šifruotą failą {file}",
    "{user} deleted {file}" : "{user} ištrynė {file}",
    "{user} deleted an encrypted file in {file}" : "{user} ištrynė šifruotą failą {file}",
    "You restored {file}" : "Jūs atkūrėte {file}",
    "{user} restored {file}" : "{user} atkūrė {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Jūs pervadinote {oldfile} (paslėptas) į {newfile} (paslėptas)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Jūs pervadinote {oldfile} (paslėptas) į {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Jūs pervadinote {oldfile} į {newfile} (paslėptas)",
    "You renamed {oldfile} to {newfile}" : " {oldfile} pervadintas į {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} pervadino {oldfile} (paslėptas) į {newfile} (paslėptas)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} pervadino {oldfile} (paslėptas) į {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} pervadino {oldfile} į {newfile} (paslėptas)",
    "{user} renamed {oldfile} to {newfile}" : "{user} pervadino {oldfile} į {newfile}",
    "You moved {oldfile} to {newfile}" : "{oldfile} perkeltas į {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} perkėlė {oldfile} į {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Failas buvo pridėtas arba pašalintas iš <strong>mėgstamų</strong>",
    "Files" : "Failai",
    "A file or folder has been <strong>changed</strong>" : "Buvo <strong>pakeistas</strong> failas ar aplankas",
    "A favorite file or folder has been <strong>changed</strong>" : "Buvo <strong>pakeistas</strong> mėgstamas failas ar aplankas",
    "Invalid folder path" : "Neteisingas aplanko kelias",
    "Folder not found" : "Aplankas nerastas",
    "The file cannot be found" : "Failas negali būti surastas",
    "The destination path does not exist: %1$s" : "Paskirties kelio nėra: %1$s",
    "You do not have permission to create a file at the specified location" : "Jūs neturite leidimo sukurti failą nurodytoje vietoje",
    "No favorites" : "Nėra mėgstamiausių",
    "Accept" : "Priimti",
    "Reject" : "Atmesti",
    "Incoming ownership transfer from {user}" : "Gaunamasis nuosavybės perdavimas nuo {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ar norite priimti {path}?\n\nPastaba: Priėmus, perdavimo procesas gali užtrukti iki 1 valandos.",
    "Ownership transfer failed" : "Nuosavybės perdavimas nepavyko",
    "Your ownership transfer of {path} to {user} failed." : "Nepavyko perduoti jūsų {path} nuosavybės naudotojui {user}.",
    "The ownership transfer of {path} from {user} failed." : "{path} nuosavybės perdavimas iš naudotojo {user} nepavyko.",
    "Ownership transfer done" : "Nuosavybės perdavimas atliktas",
    "Your ownership transfer of {path} to {user} has completed." : "Jūsų {path} nuosavybės perdavimas naudotojui {user} užbaigtas.",
    "The ownership transfer of {path} from {user} has completed." : "{path} nuosavybės perdavimas iš naudotojo {user} užbaigtas.",
    "in %s" : "per %s",
    "File Management" : "Failų tvarkymas",
    "Home" : "Pagrindinis",
    "Target folder does not exist any more" : "Paskirties aplanko daugiau nebėra",
    "Reload current directory" : "Įkelti dabartinį katalogą iš naujo",
    "Share" : "Bendrinti",
    "Drag and drop files here to upload" : "Tempkite failus čia norėdami išsiųsti",
    "Favorite" : "Mėgstamas",
    "Back" : "Atgal",
    "File is loading" : "Failas yra įkeliamas",
    "Folder is loading" : "Aplankas yra įkeliamas",
    "Filename" : "Failo pavadinimas",
    "Folder name" : "Aplanko pavadinimas",
    "Invalid filename." : "Neteisingas failo pavadinimas.",
    "Rename file" : "Pervadinti failą",
    "Folder" : "Aplankas",
    "Pending" : "Laukiantis",
    "Unknown date" : "Nežinoma data",
    "Active filters" : "Aktyvūs filtrai",
    "Remove filter" : "Šalinti filtrą",
    "Today" : "Šiandien",
    "Last 7 days" : "Paskutinės 7 dienos",
    "Last 30 days" : "Paskutinės 30 dienų",
    "Documents" : "Dokumentai",
    "Spreadsheets" : "Skaičiuoklės",
    "Presentations" : "Pateiktys",
    "PDFs" : "PDF dokumentai",
    "Folders" : "Aplankai",
    "Audio" : "Garso įrašai",
    "Images" : "Paveikslai",
    "Videos" : "Vaizdo įrašai",
    "Filters" : "Filtrai",
    "Appearance" : "Išvaizda",
    "Show hidden files" : "Rodyti paslėptus failus",
    "Crop image previews" : "Apkirpti paveikslėlių peržiūras",
    "General" : "Bendra",
    "All files" : "Visi failai",
    "Personal files" : "Asmeniniai failai",
    "Additional settings" : "Papildomi nustatymai",
    "Actions" : "Veiksmai",
    "Selection" : "Pasirinkimas",
    "Deselect all" : "Panaikinti pasirinkimą",
    "Navigation" : "Navigacija",
    "View" : "Rodyti",
    "Toggle grid view" : "Rodyti tinkleliu",
    "Warnings" : "Įspėjimai",
    "Name" : "Pavadinimas",
    "Size" : "Dydis",
    "Modified" : "Pakeistas",
    "List of files and folders." : "Failų ir aplankų sąrašas.",
    "File not found" : "Failas nerastas",
    "Owner" : "Savininkas",
    "{usedQuotaByte} used" : "Naudojama {usedQuotaByte}",
    "{used} of {quota} used" : "panaudota {used} iš {quota}",
    "{relative}% used" : "Naudojama {relative}",
    "Could not refresh storage stats" : "Nepavyko iš naujo įkelti saugyklos statistikos",
    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
    "Storage information" : "Informacija apie saugyklą",
    "New folder" : "Naujas aplankas",
    "Create new folder" : "Sukurti naują aplanką",
    "This name is already in use." : "Šis pavadinimas jau yra naudojamas.",
    "Create" : "Sukurti",
    "Refresh" : "Įkelti iš naujo",
    "Submit" : "Pateikti",
    "Choose a file or folder to transfer" : "Pasirinkite norimą perduoti failą ar aplanką",
    "Transfer" : "Perduoti",
    "Transfer {path} to {userid}" : "Perduoti {path} naudotojui {userid}",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Unknown error" : "Nežinoma klaida",
    "Ownership transfer request sent" : "Nuosavybės perdavimo užklausa išsiųsta",
    "Transfer ownership of a file or folder" : "Perduoti failo ar aplanko nuosavybę",
    "Choose file or folder to transfer" : "Pasirinkti norimą perduoti failą ar aplanką",
    "Change" : "Keisti",
    "New owner" : "Naujasis savininkas",
    "Cancel" : "Atsisakyti",
    "Rename" : "Pervadinti",
    "Choose {file}" : "Pasirinkti{file}",
    "Files settings" : "Failų nustatymai",
    "Switch to list view" : "Perjungti į sąrašo rodinį",
    "Switch to grid view" : "Perjungti į tinklelio rodinį",
    "The file could not be found" : "Failas nerastas",
    "Upload was cancelled by user" : "Įkelimas buvo atšauktas vartotojo",
    "Not enough free space" : "Trūksta laisvos vietos",
    "Operation is blocked by access control" : "Operacija yra užblokuota prieigos valdymo",
    "Error during upload: {message}" : "Įkėlimo klaida: {message}",
    "Loading current folder" : "Įkeliamas dabartinis aplankas",
    "Retry" : "Bandyti dar kartą",
    "No files in here" : "Čia failų nėra",
    "Upload some content or sync with your devices!" : "Įkelkite failus arba sinchronizuokite su savo įrenginiais!",
    "Go back" : "Grįžti",
    "Views" : "Rodiniai",
    "Loading …" : "Įkeliama …",
    "Your files" : "Jūsų failai",
    "File cannot be accessed" : "Nepavyksta gauti prieigos prie failo",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Nepavyko surasti failo arba jūs neturite leidimo jo peržiūrėti. Paprašykite siuntėjo, kad pradėtų jį su jumis bendrinti.",
    "Files compatibility" : "Failų suderinamumas",
    "Unable to create new file from template" : "Nepavyko sukurti naujo failo iš šablono",
    "Pick a template for {name}" : "Pasirinkite šabloną, skirtą {name}",
    "Create a new file with the selected template" : "Sukurti naują failą naudojant pasirinktą šabloną",
    "Creating file" : "Sukuriamas failas",
    "Save as {displayName}" : "Įrašyti kaip {displayName}",
    "Delete" : "Ištrinti",
    "Leave this share" : "Palikti bendrinimą",
    "Disconnect storage" : "Atjungti saugyklą",
    "Delete permanently" : "Ištrinti negrįžtamai",
    "Delete and unshare" : "Ištrinti ir nebebendrinti",
    "Delete file" : "Ištrinti failą",
    "Delete files" : "Ištrinti failus",
    "Delete folder" : "Ištrinti aplanką",
    "Delete folders" : "Ištrinti aplankus",
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Jūs ketinate ištrinti {count} elementą","Jūs ketinate ištrinti {count} elementus","Jūs ketinate ištrinti {count} elementų","Jūs ketinate ištrinti {count} elementą"],
    "Download" : "Atsisiųsti",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Move" : "Perkelti",
    "Copy" : "Kopijuoti",
    "Move or copy" : "Perkelti ar kopijuoti",
    "The files are locked" : "Failai yra užrakinti",
    "The file does not exist anymore" : "Failo daugiau nebėra",
    "Copy to {target}" : "Kopijuoti į {target}",
    "Move to {target}" : "Perkelti į {target}",
    "Move or copy operation failed" : "Perkėlimo ar kopijavimo operacija patyrė nesėkmę",
    "Open folder" : "Atverti aplanką",
    "Open folder {displayName}" : "Atverti aplanką {displayName}",
    "Failed to redirect to client" : "Nepavyko peradresuoti į klientą",
    "Retry and close" : "Bandyti dar kartą ir užverti",
    "Details" : "Išsamiau",
    "View in folder" : "Rodyti aplanke",
    "Type" : "Tipas",
    "Created new folder \"{name}\"" : "Sukurtas naujas aplankas „{name}“",
    "Unable to initialize the templates directory" : "Nepavyko inicijuoti šablonų katalogo",
    "Create templates folder" : "Sukurti šablonų aplanką",
    "Templates" : "Šablonai",
    "Search in folder: {folder}" : "Ieškoti aplanke: {folder}",
    "Unable to create the directory {directory}" : "Nepavyko sukurti katalogo {directory}",
    "Files copied successfully" : "Failai sėkmingai nukopijuoti",
    "Files moved successfully" : "Failai sėkmingai perkelti",
    "Some files could not be copied" : "Kai kurių failų nepavyko nukopijuoti",
    "Some files could not be moved" : "Kai kurių failų nepavyko perkelti",
    "Could not rename \"{oldName}\", it does not exist any more" : "Nepavyko pervadinti failo „{oldName}“, jo daugiau nebėra",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Pavadinimas „{newName}“ jau naudojamas aplanke „{dir}“. Pasirinkite kitokį pavadinimą.",
    "Could not rename \"{oldName}\"" : "Nepavyko pervadinti „{oldName}“",
    "This operation is forbidden" : "Ši operacija yra uždrausta",
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Unexpected error: {error}" : "Netikėta klaida: {error}",
    "_%n file_::_%n files_" : ["%n failas","%n failai","%n failų","%n failas"],
    "_%n folder_::_%n folders_" : ["%n aplankas","%n aplankai","%n aplankų","%n aplankas"],
    "Filename must not be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "„{segment}“ yra rezervuotas pavadinimas ir neleidžiamas naudoti failo pavadinimuose.",
    "\"{extension}\" is not an allowed filetype." : "„{extension}“ nėra leidžiamas failo tipas.",
    "No favorites yet" : "Kol kas nėra mėgstamų",
    "Files and folders you mark as favorite will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos pažymėsite kaip mėgstamus",
    "List of your files and folders." : "Jūsų failų ir aplankų sąrašas.",
    "No personal files found" : "Nerasta jokių asmeninių failų",
    "Recent" : "Paskiausiai naudoti",
    "List of recently modified files and folders." : "Paskiausiai modifikuotų failų ir aplankų sąrašas.",
    "No recently modified files" : "Nėra jokių paskiausiai modifikuotų failų",
    "Search" : "Paieška",
    "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
    "Select all" : "Pažymėti viską",
    "Upload too large" : "Įkėlimui failas per didelis",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
    "Upload (max. %s)" : "Įkelti (maks. %s)",
    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}“ pervadintas į „{newName}“",
    "Clear filter" : "Išvalyti filtrą",
    "Shared by link" : "Bendrinama pagal nuorodą",
    "Shared" : "Bendrinama",
    "Clipboard is not available" : "Iškarpinė neprieinama",
    "WebDAV URL copied to clipboard" : "WebDAV URL nukopijuotas į iškarpinę",
    "Enable the grid view" : "Įjungti grid peržiūrą",
    "Enable folder tree" : "Įjungti direktorijų medį",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopijuoti į iškarpinę",
    "Use this address to access your Files via WebDAV" : "Naudokite šį adresą norėdami pasiekti failus per WebDAV",
    "Keyboard shortcuts" : "Spartieji klavišai",
    "Rename a file" : "Pervadinti failą",
    "Delete a file" : "Ištrinti failą",
    "You" : "Jūs",
    "Error while loading the file data" : "Klaida įkeliant failo duomenis",
    "Tags" : "Žymos",
    "Save as …" : "Įrašyti kaip…",
    "Deletion cancelled" : "Ištrynimo atsisakyta",
    "Edit locally" : "Redaguoti lokaliai",
    "Moving \"{source}\" to \"{destination}\" …" : "Perkeliama „{source}“ į „{destination}“…",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopijuojama „{source}“ į „{destination}“…",
    "(copy)" : "(kopija)",
    "(copy %n)" : "(kopija %n)",
    "Open details" : "Atverti išsamesnę informaciją",
    "Photos and images" : "Nuotraukos ir paveikslai",
    "New folder creation cancelled" : "Naujo aplanko sukūrimo atsisakyta",
    "This directory is unavailable, please check the logs or contact the administrator" : "Šis katalogas neprieinamas, peržiūrėkite žurnalo įrašus arba susisiekite su administratoriumi",
    "All folders" : "Visi aplankai"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
